package com.muyu.vehicle.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.domain.req.FaultRecordReqVo;
import com.muyu.domain.vo.FaultRecordVo;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.FaultRecord;
import com.muyu.domain.req.FaultRecordEditReq;
import com.muyu.domain.req.FaultRecordQueryReq;
import com.muyu.domain.req.FaultRecordSaveReq;

import com.muyu.domain.vo.FaultRecordVo;
import com.muyu.vehicle.service.FaultRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/** 车辆故障记录
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/6/20 15:26
 */
@Api(tags = "故障记录")
@RestController
@RequestMapping("/faultRecord")
public class FaultRecordController extends BaseController {
    @Autowired
    private FaultRecordService faultRecordService;

    /**
     * 查询故障记录列表
     */
    @ApiOperation("获取故障记录列表")

    @GetMapping("/list")
    public Result<TableDataInfo<FaultRecord>> list(FaultRecordQueryReq faultRecordQueryReq) {
        startPage();
        List<FaultRecord> list = faultRecordService.list(FaultRecord.queryBuild(faultRecordQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出故障记录列表
     */
    @ApiOperation("导出故障记录列表")

    @Log(title = "故障记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaultRecord faultRecord) {
        List<FaultRecord> list = faultRecordService.list(faultRecord);
        ExcelUtil<FaultRecord> util = new ExcelUtil<FaultRecord>(FaultRecord.class);
        util.exportExcel(response, list, "故障记录数据");
    }

    /**
     * 获取故障记录详细信息
     */
    @ApiOperation("获取故障记录详细信息")

    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<FaultRecord> getInfo(@PathVariable("id") Long id) {
        return Result.success(faultRecordService.getById(id));
    }

    /**
     * 新增故障记录
     */

    @Log(title = "故障记录", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增故障记录")
    public Result<String> add(@RequestBody FaultRecordSaveReq faultRecordSaveReq) {
        return toAjax(faultRecordService.save(FaultRecord.saveBuild(faultRecordSaveReq)));
    }

    /**
     * 修改故障记录
     */

    @Log(title = "故障记录", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改故障记录")
    public Result<String> edit(@PathVariable Long id, @RequestBody FaultRecordEditReq faultRecordEditReq) {
        return toAjax(faultRecordService.updateById(FaultRecord.editBuild(id,faultRecordEditReq)));
    }

    /**
     * 删除故障记录
     */

    @Log(title = "故障记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation("删除故障记录")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(faultRecordService.removeBatchByIds(ids));
    }



    @Log(title = "图",businessType = BusinessType.DELETE)
    @PostMapping("/countList")
    @ApiOperation("图展示")
    public Result<List<FaultRecordVo>> countList(@RequestBody FaultRecordReqVo recordReqVo) {
        return Result.success(faultRecordService.countList(recordReqVo));
    }

}
