package com.muyu.vehicle.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.data.MessageDetail;
import com.muyu.domain.req.MessageDetailEditReq;
import com.muyu.domain.req.MessageDetailQueryReq;
import com.muyu.domain.req.MessageDetailSaveReq;
import com.muyu.vehicle.service.MessageDetailService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/6/26 21:52
 */
@Api(tags = "报文详情")
@RestController
@RequestMapping("/messageDetail")
public class MessageDetailController extends BaseController {

    @Autowired
    private MessageDetailService messageDetailService;

    /**
     * 查询报文详情列表
     */
    @ApiOperation("获取报文详情列表")
    @GetMapping("/list")
    public Result<TableDataInfo<MessageDetail>> list(MessageDetailQueryReq messageDetailQueryReq) {
        startPage();
        List<MessageDetail> list = messageDetailService.list(MessageDetail.queryBuild(messageDetailQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出报文详情列表
     */
    @ApiOperation("导出报文详情列表")
    @Log(title = "报文详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MessageDetail messageDetail) {
        List<MessageDetail> list = messageDetailService.list(messageDetail);
        ExcelUtil<MessageDetail> util = new ExcelUtil<MessageDetail>(MessageDetail.class);
        util.exportExcel(response, list, "报文详情数据");
    }

    /**
     * 获取报文详情详细信息
     */
    @ApiOperation("获取报文详情详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<MessageDetail> getInfo(@PathVariable("id") Long id) {
        return Result.success(messageDetailService.getById(id));
    }

    /**
     * 新增报文详情
     */

    @Log(title = "报文详情", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增报文详情")
    public Result<String> add(@RequestBody MessageDetailSaveReq messageDetailSaveReq) {
        return toAjax(messageDetailService.save(MessageDetail.saveBuild(messageDetailSaveReq)));
    }

    /**
     * 修改报文详情
     */
    @Log(title = "报文详情", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改报文详情")
    public Result<String> edit(@PathVariable Long id, @RequestBody MessageDetailEditReq messageDetailEditReq) {
        return toAjax(messageDetailService.updateById(MessageDetail.editBuild(id,messageDetailEditReq)));
    }

    /**
     * 删除报文详情
     */
    @Log(title = "报文详情", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation("删除报文详情")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(messageDetailService.removeBatchByIds(ids));
    }

    @PostMapping("/submit")
    public Result submit(@RequestBody MessageDetail vehicleMessages){
        messageDetailService.submit(vehicleMessages);
        return Result.success();
    }



}
