package com.muyu.vehicle.myDatasource.aspect;

import com.muyu.common.core.domain.Result;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.vehicle.myDatasource.holder.DynamicDataSourceHolder;
import org.aspectj.lang.annotation.After;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/6/10 20:02
 */
@Aspect
@Component
public class DataSourceAsp {
    @Autowired
    private RemoteUserService remoteUserService;

    @Pointcut("execution(public * com.muyu.vehicle.controller.*Controller.*(..))")
    public void pointcut() {
    }

    /**
     * 的每一個方法執行之前 執行的處理
     */
    @Before("pointcut()")
    public void beforeMethod() {
        LoginUser loginUser = SecurityUtils.getLoginUser();
        Long userid = loginUser.getUserid();
        Result<SysUser> sysUserResult = remoteUserService.selectUserById(userid);
        SysUser sysUser = sysUserResult.getData();
        DynamicDataSourceHolder.setDynamicDataSourceKey("ent" + sysUser.getEnterpriseId());


    }

    /**
     * 的每一個方法執行之后 執行的處理
     * 无论正常还是异常终了
     * 不能接受到返回值
     */
    @After("pointcut()")
    public void afterMethod() {
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

}
