package com.muyu.vehicle.rabbit;
import com.alibaba.fastjson.JSON;
import com.muyu.domain.FaultRecord;

import com.muyu.domain.Information;

import com.muyu.vehicle.myDatasource.holder.DynamicDataSourceHolder;

import com.muyu.vehicle.service.FaultRecordService;
import com.muyu.vehicle.service.IInformationService;
import com.rabbitmq.client.Channel;
import lombok.extern.log4j.Log4j2;

import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;


import java.io.IOException;

import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/** 监听基础事件的数据
 * @ClassDescription:
 * @JdkVersion: 17
 * @Author: zhangxu
 * @Created: 2024/6/21 9:41
 */
@Component
@Log4j2
public class Consumer {
    private static final String QUEUE_NAME_EVENT_START = "zhiLian-vehicle-start";
    private static final String QUEUE_NAME_EVENT_ENT = "zhiLian-vehicle-end";

    @Autowired
    private FaultRecordService recordService;
    @Autowired
    private IInformationService service;




    @Autowired
    private RedisTemplate<String,String> redisTemplate;



    public void manyJob(){

        DynamicDataSourceHolder.setDynamicDataSourceKey("ent5");

        List<Information> list = service.selectVehicleListAll(new Information());

        ExecutorService executor = Executors.newFixedThreadPool(list.size());

        list.forEach(information -> {

            executor.submit(new Runnable() {

                @Override

                public void run() {

                    redisTemplate.opsForValue().set(information.getNumber()+"1", String.valueOf(information.getEnterpriseId()));
                }
            });
        });
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }
    @RabbitListener( queuesToDeclare= {@Queue(name = QUEUE_NAME_EVENT_START)})
    public void receive(String msg, Channel channel, Message message) {
        //获取消息的ID
        String messageId = message.getMessageProperties().getMessageId();
        try {
            Long count = redisTemplate.opsForSet().add("messageId", messageId);
            if (count==1) {
                log.info("故障开始消费！{}", msg);
                manyJob();
                FaultRecord faultRecord = JSON.parseObject(msg, FaultRecord.class);
                //判断车辆属于哪个企业
                String s = redisTemplate.opsForValue().get(faultRecord.getVin()+"1");
                // 进行添加故障表
                Executors.newFixedThreadPool(1). execute(new Runnable() {
                    @Override
                    public void run() {
                        //选择数据源，切换数据源，
                        DynamicDataSourceHolder.setDynamicDataSourceKey("ent"+Integer.valueOf(s));
                        FaultRecord build = FaultRecord
                                .builder()
                                .faultCode(faultRecord.getFaultCode())
                                .vin(faultRecord.getVin())
                                .startTime(faultRecord.getStartTime()).build();
                        recordService.save(build);
                        // 移除数据源，
                        DynamicDataSourceHolder.removeDynamicDataSourceKey();
                    }
                });
                channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
                log.info("消费成功！数据源为：{}",message);
            }
        } catch (IOException e) {
            log.info("消费失败，{}",e.getMessage());
            try {
                //回退消息
                channel.basicReject(message.getMessageProperties().getDeliveryTag(),false);
                log.info("回退成功");
            }catch (IOException ex){
                log.info("回退失败:{}",ex.getMessage());
            }
            throw new RuntimeException(e);
        }
    }


    @RabbitListener(queuesToDeclare = {@Queue(name = QUEUE_NAME_EVENT_ENT)})
    public void receive2(String msg, Channel channel, Message message) {
        //获取消息的ID
        String messageId = message.getMessageProperties().getMessageId();
        try {
            //添加消息id到redis set集合中  添加成功返回1 表示未消费    添加失败返回0 表示已消费
            Long count = redisTemplate.opsForSet().add("messageId", messageId);
            //添加成功  正常消费信息
            if (count == 1) {
                log.info("故障结束消费:{}",msg);
                manyJob();
                FaultRecord faultRecord = JSON.parseObject(msg, FaultRecord.class);
                //判断车辆属于哪个企业
                String s = redisTemplate.opsForValue().get(faultRecord.getVin()+"1");
                Executors.newFixedThreadPool(1).execute(new Runnable() {
                    @Override
                    public void run() {
                        //选择数据源，切换数据源，
                        DynamicDataSourceHolder.setDynamicDataSourceKey("ent"+Integer.valueOf(s));
                        // 进行查询故障表
                        FaultRecord faultRecordOne = recordService.getByFaultRecord(faultRecord);
                        log.info("查询到的故障为：{}",faultRecordOne);
                        faultRecordOne.setEndTime(faultRecord.getEndTime());
                        // 进行修改故障表
                        recordService.updateByFaultRecord(faultRecordOne);
                        // 移除数据源，
                        DynamicDataSourceHolder.removeDynamicDataSourceKey();

                    }

                });
                //确认消费
                channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
                log.info("消费成功");
            }

        } catch (Exception e) {
            //删除队列ID
            log.info("消费失败，{}",e.getMessage());

            try {
                //回退消息
                channel.basicReject(message.getMessageProperties().getDeliveryTag(),false);
                log.info("回退消息");
            } catch (IOException ex) {
                //回退失败
                log.info("回退失败");

            }

        }

    }

}

